# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_auth
from openapi_auth.model.aptos_complete_challenge_request_dto import AptosCompleteChallengeRequestDto
from openapi_auth import configuration


class TestAptosCompleteChallengeRequestDto(unittest.TestCase):
    """AptosCompleteChallengeRequestDto unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
