# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_aptos_api
from openapi_aptos_api.model.coin_transfer_dto import CoinTransferDto
from openapi_aptos_api import configuration


class TestCoinTransferDto(unittest.TestCase):
    """CoinTransferDto unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
