# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_auth.paths.bind_remove.post import RemoveBind
from openapi_auth.paths.bind_request.post import RequestBind
from openapi_auth.paths.bind_remove_verify.post import VerifyRemoveBind
from openapi_auth.paths.bind_request_verify.post import VerifyRequestBind


class BindApi(
    RemoveBind,
    RequestBind,
    VerifyRemoveBind,
    VerifyRequestBind,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
