# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.wallets_coins.get import GetCoinBalancesByWallets
from openapi_aptos_api.paths.wallets_coins_transfers.get import GetCoinTransfersByWalletAddresses
from openapi_aptos_api.paths.wallets_coins_history.get import GetHistoricalCoinBalancesByWallets
from openapi_aptos_api.paths.wallets_nfts.get import GetNftByOwners
from openapi_aptos_api.paths.wallets_nfts_transfers.get import GetWalletsNftTransfers


class WalletsApi(
    GetCoinBalancesByWallets,
    GetCoinTransfersByWalletAddresses,
    GetHistoricalCoinBalancesByWallets,
    GetNftByOwners,
    GetWalletsNftTransfers,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
