# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_evm_api
from openapi_evm_api.model.erc20_burn_response import Erc20BurnResponse
from openapi_evm_api import configuration


class TestErc20BurnResponse(unittest.TestCase):
    """Erc20BurnResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
