# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosCoinDeposit(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "sequenceNumber",
            "address",
            "valueWithDecimals",
            "value",
            "coin",
        }
        
        class properties:
            sequenceNumber = schemas.StrSchema
            valueWithDecimals = schemas.StrSchema
        
            @staticmethod
            def coin() -> typing.Type['AptosCoin']:
                return AptosCoin
            address = schemas.StrSchema
            value = schemas.StrSchema
            __annotations__ = {
                "sequenceNumber": sequenceNumber,
                "valueWithDecimals": valueWithDecimals,
                "coin": coin,
                "address": address,
                "value": value,
            }
    
    sequenceNumber: MetaOapg.properties.sequenceNumber
    address: MetaOapg.properties.address
    valueWithDecimals: MetaOapg.properties.valueWithDecimals
    value: MetaOapg.properties.value
    coin: 'AptosCoin'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sequenceNumber"]) -> MetaOapg.properties.sequenceNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["sequenceNumber", "valueWithDecimals", "coin", "address", "value", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sequenceNumber"]) -> MetaOapg.properties.sequenceNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["sequenceNumber", "valueWithDecimals", "coin", "address", "value", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        sequenceNumber: typing.Union[MetaOapg.properties.sequenceNumber, str, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        valueWithDecimals: typing.Union[MetaOapg.properties.valueWithDecimals, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        coin: 'AptosCoin',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosCoinDeposit':
        return super().__new__(
            cls,
            *args,
            sequenceNumber=sequenceNumber,
            address=address,
            valueWithDecimals=valueWithDecimals,
            value=value,
            coin=coin,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.aptos_coin import AptosCoin
