# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_sol_api import schemas  # noqa: F401


class NFTMetadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "standard",
            "mint",
            "symbol",
            "metaplex",
            "name",
        }
        
        class properties:
            mint = schemas.StrSchema
            standard = schemas.StrSchema
            name = schemas.StrSchema
            symbol = schemas.StrSchema
        
            @staticmethod
            def metaplex() -> typing.Type['MetaplexNFT']:
                return MetaplexNFT
            __annotations__ = {
                "mint": mint,
                "standard": standard,
                "name": name,
                "symbol": symbol,
                "metaplex": metaplex,
            }
    
    standard: MetaOapg.properties.standard
    mint: MetaOapg.properties.mint
    symbol: MetaOapg.properties.symbol
    metaplex: 'MetaplexNFT'
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mint"]) -> MetaOapg.properties.mint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["standard"]) -> MetaOapg.properties.standard: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metaplex"]) -> 'MetaplexNFT': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["mint", "standard", "name", "symbol", "metaplex", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mint"]) -> MetaOapg.properties.mint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["standard"]) -> MetaOapg.properties.standard: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metaplex"]) -> 'MetaplexNFT': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["mint", "standard", "name", "symbol", "metaplex", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        standard: typing.Union[MetaOapg.properties.standard, str, ],
        mint: typing.Union[MetaOapg.properties.mint, str, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        metaplex: 'MetaplexNFT',
        name: typing.Union[MetaOapg.properties.name, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NFTMetadata':
        return super().__new__(
            cls,
            *args,
            standard=standard,
            mint=mint,
            symbol=symbol,
            metaplex=metaplex,
            name=name,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_sol_api.model.metaplex_nft import MetaplexNFT
