# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.paths.accounts_address_resource_module_name import Api

from openapi_aptos_api.paths import PathValues

path = PathValues.ACCOUNTS_ADDRESS_RESOURCE_MODULE_NAME