# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.paths.nfts_collections_collection_data_id_hash_tokens import Api

from openapi_aptos_api.paths import PathValues

path = PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_TOKENS