# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.transactions_encode_submission.post import EncodeSubmission
from openapi_aptos_api.paths.accounts_address_transactions.get import GetAccountTransactions
from openapi_aptos_api.paths.blocks_block_height.get import GetBlockByHeight
from openapi_aptos_api.paths.blocks_by_version_version.get import GetBlockByVersion
from openapi_aptos_api.paths.transactions_by_hash_txn_hash.get import GetTransactionByHash
from openapi_aptos_api.paths.transactions_by_version_txn_version.get import GetTransactionByVersion
from openapi_aptos_api.paths.transactions.get import GetTransactions
from openapi_aptos_api.paths.transactions_simulate.post import SimulateTransaction
from openapi_aptos_api.paths.transactions_batch.post import SubmitBatchTransactions
from openapi_aptos_api.paths.transactions.post import SubmitTransaction


class DefaultApi(
    EncodeSubmission,
    GetAccountTransactions,
    GetBlockByHeight,
    GetBlockByVersion,
    GetTransactionByHash,
    GetTransactionByVersion,
    GetTransactions,
    SimulateTransaction,
    SubmitBatchTransactions,
    SubmitTransaction,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
