# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The stream status:
[active] The Stream is healthy and processing blocks
[paused] The Stream is paused and is not processing blocks
[error] The Stream has encountered an error and is not processing blocks
    """


    class MetaOapg:
        enum_value_to_name = {
            "active": "ACTIVE",
            "paused": "PAUSED",
            "error": "ERROR",
            "terminated": "TERMINATED",
        }
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("active")
    
    @schemas.classproperty
    def PAUSED(cls):
        return cls("paused")
    
    @schemas.classproperty
    def ERROR(cls):
        return cls("error")
    
    @schemas.classproperty
    def TERMINATED(cls):
        return cls("terminated")
