# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class SettingsRegion(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "us-east-1": "USEAST1",
            "us-west-2": "USWEST2",
            "eu-central-1": "EUCENTRAL1",
            "ap-southeast-1": "APSOUTHEAST1",
        }
    
    @schemas.classproperty
    def USEAST1(cls):
        return cls("us-east-1")
    
    @schemas.classproperty
    def USWEST2(cls):
        return cls("us-west-2")
    
    @schemas.classproperty
    def EUCENTRAL1(cls):
        return cls("eu-central-1")
    
    @schemas.classproperty
    def APSOUTHEAST1(cls):
        return cls("ap-southeast-1")
