# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.info_endpoint_weights.get import EndpointWeights
from openapi_evm_api.paths.address_function.post import RunContractFunction
from openapi_evm_api.paths.web3_version.get import Web3ApiVersion


class UtilsApi(
    EndpointWeights,
    RunContractFunction,
    Web3ApiVersion,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
