# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.coins.get import GetCoinInfoByCoinTypeHashes
from openapi_aptos_api.paths.coins_transfers_blocks.get import GetCoinTransfersByBlockHeights
from openapi_aptos_api.paths.coins_transfers_coin_type.get import GetCoinTransfersByCoinType
from openapi_aptos_api.paths.coins_transfers_wallets.get import GetCoinTransfersByOwnerAddresses
from openapi_aptos_api.paths.coins_creators.get import GetCoinsByCreators
from openapi_aptos_api.paths.coins_names.get import GetCoinsByNameRange
from openapi_aptos_api.paths.coins_symbols.get import GetCoinsBySymbolRange
from openapi_aptos_api.paths.coins_latest.get import GetLatestCoins
from openapi_aptos_api.paths.coins_owners_coin_type_hash_top_holders.get import GetTopHoldersByCoin


class CoinsApi(
    GetCoinInfoByCoinTypeHashes,
    GetCoinTransfersByBlockHeights,
    GetCoinTransfersByCoinType,
    GetCoinTransfersByOwnerAddresses,
    GetCoinsByCreators,
    GetCoinsByNameRange,
    GetCoinsBySymbolRange,
    GetLatestCoins,
    GetTopHoldersByCoin,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
