# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.accounts_address.get import GetAccount
from openapi_aptos_api.paths.accounts_address_resource_module_name.get import GetAccountModule
from openapi_aptos_api.paths.accounts_address_modules.get import GetAccountModules
from openapi_aptos_api.paths.accounts_address_resource_resource_type.get import GetAccountResource
from openapi_aptos_api.paths.accounts_address_resources.get import GetAccountResources
from openapi_aptos_api.paths.accounts_address_events_creation_number.get import GetEventsByCreationNumber
from openapi_aptos_api.paths.accounts_address_events_event_handle_field_name.get import GetEventsByEventHandle


class AccountsApi(
    GetAccount,
    GetAccountModule,
    GetAccountModules,
    GetAccountResource,
    GetAccountResources,
    GetEventsByCreationNumber,
    GetEventsByEventHandle,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
